@@ -68,8 +68,10 @@ hr_plot = function(.data, dependent, explanatory, factorlist=NULL, coxfit=NULL,
       dplyr::mutate(label = ifelse(label == "", NA, label)) %>% 
       tidyr::fill(label) %>% 
       dplyr::group_by(label) %>%
-      dplyr::slice(2:dplyr::n()) %>% 
-      rm_duplicate_labels()
+      #dplyr::slice(2:dplyr::n()) %>% 
+      dplyr::filter(dplyr::row_number() != 1 | 
+                      dplyr::n() > 2) %>% 
+    rm_duplicate_labels()
   }
 
   # Specify breaks if provided
