@@ -18,8 +18,8 @@ colon_s$smoking_mcar =
   sample(c("Smoker", "Non-smoker", NA), 
     dim(colon_s)[1], replace=TRUE, 
     prob = c(0.2, 0.7, 0.1)) %>% 
-  factor()
-Hmisc::label(colon_s$smoking_mcar) = "Smoking (MCAR)"
+  factor() %>% 
+	ff_label("Smoking (MCAR)")
 
 ## Smoking missing conditional on patient sex
 colon_s$smoking_mar[colon_s$sex.factor == "Female"] = 
@@ -32,8 +32,8 @@ colon_s$smoking_mar[colon_s$sex.factor == "Male"] =
   sample(c("Smoker", "Non-smoker", NA), 
     sum(colon_s$sex.factor == "Male"), 
     replace=TRUE, prob = c(0.15, 0.75, 0.1))
-colon_s$smoking_mar = factor(colon_s$smoking_mar)
-Hmisc::label(colon_s$smoking_mar) = "Smoking (MAR)"
+colon_s$smoking_mar = factor(colon_s$smoking_mar) %>% 
+	ff_label("Smoking (MAR)")
 
 # Examine with ff_glimpse
 explanatory = c("age", "sex.factor", 
